import { __assign } from "tslib";
import { isObject } from 'lodash';
import { addDefaultArgs, getArgsString } from './utils';
import { FIREBASE_TOOLS_BASE_COMMAND, FIREBASE_EXTRA_PATH } from './constants';
/**
 * Build Command to run Firestore action. Commands call either firebase-extra
 * (in bin/firebaseExtra.js) or firebase-tools directly. FIREBASE_TOKEN must
 * exist in environment if running commands that call firebase-tools.
 * @param Cypress - Cypress object
 * @param action - action to run on Firstore (i.e. "add", "delete")
 * @param actionPath - Firestore path where action should be run
 * @param fixturePath - Path to fixture. If object is passed,
 * it is used as options.
 * @param [opts={}] - Options object
 * @param opts.args - Extra arguments to be passed with command
 * @param opts.token - Firebase CI token to pass as the token argument
 * @returns Command string to be used with cy.exec
 */
export default function buildFirestoreCommand(Cypress, action, actionPath, fixturePath, opts) {
    if (opts === void 0) { opts = {}; }
    var options = isObject(fixturePath) ? fixturePath : opts;
    var _a = options.args, args = _a === void 0 ? [] : _a;
    var argsWithDefaults = addDefaultArgs(Cypress, args, __assign(__assign({}, options), { disableYes: true }));
    switch (action) {
        case 'delete': {
            var deleteArgsWithDefaults = addDefaultArgs(Cypress, args);
            // Add -r to args string (recursive) if recursive option is true otherwise specify shallow
            var finalDeleteArgs = deleteArgsWithDefaults.concat(options && options.recursive ? '-r' : '--shallow');
            var deleteArgsStr = getArgsString(finalDeleteArgs);
            return FIREBASE_TOOLS_BASE_COMMAND + " firestore:" + action + " " + actionPath + deleteArgsStr;
        }
        case 'set': {
            // Add -m to argsWithDefaults string (meta) if withmeta option is true
            return FIREBASE_EXTRA_PATH + " firestore " + action + " " + actionPath + " '" + JSON.stringify(fixturePath) + "'" + (options && options.withMeta ? ' -m' : '');
        }
        default: {
            // Add -m to argsWithDefaults string (meta) if withmeta option is true
            if (options && options.withMeta) {
                argsWithDefaults.push('-m');
            }
            return FIREBASE_EXTRA_PATH + " firestore " + action + " " + actionPath + " '" + JSON.stringify(fixturePath) + "'";
        }
    }
}
