/**
 * Get settings from firebaserc file
 * @param filePath - Path for file
 * @returns Firebase settings object
 */
export declare function readJsonFile(filePath: string): any;
/**
 * Get prefix for current environment based on environment vars available
 * within CI. Falls back to staging (i.e. STAGE)
 * @param envName - Environment option
 * @returns Environment prefix string
 */
export declare function getEnvPrefix(envName?: string): string;
/**
 * Get cypress folder path from cypress.json config file or fallback to
 * default folder path ('cypress')
 * @returns Path of folder containing cypress folders like "integration"
 */
export declare function getCypressFolderPath(): string;
/**
 * Get path to cypress config file
 * @returns Path to cypress config file
 */
export declare function getCypressConfigPath(): string;
/**
 * Get environment variable based on the current CI environment
 * @param varNameRoot - variable name without the environment prefix
 * @param envName - Environment option
 * @returns Value of the environment variable
 * @example
 * envVarBasedOnCIEnv('FIREBASE_PROJECT_ID')
 * // => 'fireadmin-stage' (value of 'STAGE_FIREBASE_PROJECT_ID' environment var)
 */
export declare function envVarBasedOnCIEnv(varNameRoot: string, envName?: string): any;
interface ServiceAccount {
    type: string;
    project_id: string;
    private_key_id: string;
    private_key: string;
    client_email: string;
    client_id: string;
    auth_uri: string;
    token_uri: string;
    auth_provider_x509_cert_url: string;
    client_x509_cert_url: string;
}
/**
 * Get service account from either local file or environment variables
 * @param envSlug - Environment option
 * @returns Service account object
 */
export declare function getServiceAccount(envSlug: string): ServiceAccount;
export interface RunCommandOptions {
    command: string;
    args: string[];
    beforeMsg?: string;
    successMsg?: string;
    errorMsg?: string;
    pipeOutput?: boolean;
}
/**
 * Run a bash command using spawn pipeing the results to the main process
 * @param runOptions - Options for command run
 * @param runOptions.command - Command to be executed
 * @param runOptions.args - Command arguments
 * @returns Resolves with results of running the command
 * @private
 */
export declare function runCommand(runOptions: RunCommandOptions): Promise<any>;
export {};
