/**
 * Async await wrapper for easy error handling
 * @param promise - Promise to wrap responses of in array
 * @param errorExt - Extension for error
 * @returns Resolves and rejects with an array
 */
export declare function to<T, U = Error>(promise: Promise<T>, errorExt?: object): Promise<[U | null, T | undefined]>;
/**
 * Convert slash path to Firestore reference
 * @param firestoreInstance - Instance on which to
 * create ref
 * @param slashPath - Path to convert into firestore refernce
 * @param options - Options object
 * @returns Ref at slash path
 */
export declare function slashPathToFirestoreRef(firestoreInstance: any, slashPath: string, options?: any): any;
/**
 * Create command arguments string from an array of arguments by joining them
 * with a space including a leading space. If no args provided, empty string
 * is returned
 * @param args - Command arguments to convert into a string
 * @returns Arguments section of command string
 */
export declare function getArgsString(args: string[] | any): string;
/**
 * Add default Firebase arguments to arguments array.
 * @param Cypress - Cypress object
 * @param args - arguments array
 * @param [opts={}] - Options object
 * @param opts.token - Firebase CI token to pass as the token argument
 * @param [opts.disableYes=false] - Whether or not to disable the yes argument
 * @returns Default args list
 */
export declare function addDefaultArgs(Cypress: any, args: string[], opts?: any): string[];
/**
 * Check to see if the provided value is a promise object
 * @param valToCheck - Value to be checked for Promise qualities
 * @returns Whether or not provided value is a promise
 */
export declare function isPromise(valToCheck: any): boolean;
/**
 * Escape shell command arguments and join them to a single string
 * @param a - List of arguments to escape
 * @returns Command string with arguments escaped
 */
export declare function shellescape(a: string[]): string;
